"use strict";
const utils_request = require("../utils/request.js");
function getAppVersion() {
  return utils_request.request({
    url: `/api/app/Version`
  });
}
function getDictionaryDataAll() {
  return utils_request.request({
    url: "/api/system/DictionaryData/All",
    options: {
      load: false
    }
  });
}
function getDictionaryDataSelector(dictionaryTypeId) {
  return utils_request.request({
    url: `/api/system/DictionaryData/${dictionaryTypeId}/Data/Selector`,
    options: {
      load: false
    }
  });
}
function getDataChange(modelId, id) {
  return utils_request.request({
    url: `/api/visualdev/OnlineDev/${modelId}/${id}/DataChange`,
    method: "GET"
  });
}
function getRelationSelect(id, data, options) {
  return utils_request.request({
    url: `/api/visualdev/Base/${id}/FieldDataSelect`,
    data,
    options: {
      load: false
    }
  });
}
function getPopSelect(id, data, options) {
  return utils_request.request({
    url: `/api/system/DataInterface/${id}/Actions/List`,
    method: "POST",
    data,
    options: {
      load: true
    }
  });
}
function getDataInterfaceDataInfoByIds(id, data) {
  return utils_request.request({
    url: `/api/system/DataInterface/${id}/Actions/InfoByIds`,
    method: "POST",
    data
  });
}
function getOrganizeSelector() {
  return utils_request.request({
    url: "/api/permission/Organize/Selector/0",
    options: {
      load: false
    }
  });
}
function getDepartmentSelector() {
  return utils_request.request({
    url: "/api/permission/Organize/Department/Selector/0",
    options: {
      load: false
    }
  });
}
function getPositionSelector() {
  return utils_request.request({
    url: "/api/permission/Position/Selector",
    options: {
      load: false
    }
  });
}
function getUserSelector() {
  return utils_request.request({
    url: "/api/permission/Users/Selector",
    options: {
      load: false
    }
  });
}
const getOrgByOrganizeCondition = (data) => {
  return utils_request.request({
    url: `/api/permission/Organize/OrganizeCondition`,
    method: "post",
    data
  });
};
const getPositionByPositionCondition = (data) => {
  return utils_request.request({
    url: `/api/permission/Position/PositionCondition`,
    method: "post",
    data
  });
};
function getUserSelectorNew(organizeId, keyword) {
  return utils_request.request({
    url: `/api/permission/Users/ImUser/Selector/${organizeId}`,
    method: "POST",
    data: {
      keyword
    },
    options: {
      load: false
    }
  });
}
const getUserInfoList = (ids) => {
  return utils_request.request({
    url: "/api/permission/Users/getUserList",
    method: "post",
    data: {
      ids
    }
  });
};
const getSubordinates = (keyword) => {
  return utils_request.request({
    url: "/api/permission/Users/getSubordinates",
    method: "post",
    data: {
      keyword
    }
  });
};
const getOrganization = (keyword) => {
  return utils_request.request({
    url: "/api/permission/Users/getOrganization",
    method: "get",
    data: {
      keyword,
      organizeId: "0"
    }
  });
};
function getUesrDetail(id) {
  return utils_request.request({
    url: "/api/app/User/" + id,
    method: "GET"
  });
}
function getUserAll() {
  return utils_request.request({
    url: "/api/permission/Users/All",
    options: {
      load: false
    }
  });
}
function getImUser(data, options) {
  return utils_request.request({
    url: "/api/permission/Users/ImUser",
    data,
    options: {
      load: false
    }
  });
}
function getDataInterfaceRes(id, data) {
  return utils_request.request({
    url: `/api/system/DataInterface/${id}/Actions/Preview`,
    method: "post",
    options: {
      load: false
    },
    data: data || {}
  });
}
function login(data) {
  return utils_request.request({
    url: "/api/oauth/Login",
    method: "post",
    data,
    header: {
      "Content-Type": "application/x-www-form-urlencoded"
    }
  });
}
function accountCancel(token) {
  return utils_request.request({
    url: "/api/oauth/logoutCurrentUser",
    method: "post",
    token,
    header: {
      "Content-Type": "application/x-www-form-urlencoded"
    }
  });
}
function logout() {
  return utils_request.request({
    url: "/api/oauth/Logout"
  });
}
function getCurrentUser() {
  return utils_request.request({
    url: "/api/oauth/CurrentUser?type=app",
    options: {
      load: false
    }
  });
}
function updatePasswordMessage() {
  return utils_request.request({
    url: "/api/oauth/updatePasswordMessage",
    method: "POST",
    options: {
      load: false
    }
  });
}
function getBillNumber(enCode) {
  return utils_request.request({
    url: `/api/system/BillRule/BillNumber/${enCode}`,
    method: "GET",
    options: {
      load: false
    }
  });
}
function getSystemConfig() {
  return utils_request.request({
    url: "/api/system/SysConfig",
    method: "GET"
  });
}
function getDownloadUrl(type, fileId) {
  return utils_request.request({
    url: `/api/file/Download/${type}/${fileId}`,
    method: "GET"
  });
}
function updatePassword(data) {
  return utils_request.request({
    url: "/api/permission/Users/Current/Actions/ModifyPassword",
    method: "POST",
    data
  });
}
function getSubordinate(id) {
  return utils_request.request({
    url: `/api/permission/Users/Current/Subordinate/${id ? id : "0"}`,
    method: "GET"
  });
}
function getConfig(account) {
  return utils_request.request({
    url: `/api/oauth/getConfig/${account}`,
    method: "get"
  });
}
function getProvinceSelector(id) {
  return utils_request.request({
    url: `/api/system/Area/${id}/Selector/0`,
    method: "GET"
  });
}
function getProvinceSelectorInfoList(idsList) {
  return utils_request.request({
    url: `/api/system/Area/GetAreaByIds`,
    method: "post",
    data: {
      idsList
    }
  });
}
function setMajor(data) {
  return utils_request.request({
    url: `/api/permission/Users/Current/major`,
    method: "put",
    data
  });
}
function getUserOrganizes(data) {
  return utils_request.request({
    url: `/api/permission/Users/Current/getUserOrganizes`,
    method: "GET",
    data
  });
}
function getUserPositions(data) {
  return utils_request.request({
    url: `/api/permission/Users/Current/getUserPositions`,
    method: "GET",
    data
  });
}
function UserSettingInfo() {
  return utils_request.request({
    url: "/api/permission/Users/Current/BaseInfo",
    method: "GET"
  });
}
function UpdateUser(data) {
  return utils_request.request({
    url: "/api/permission/Users/Current/BaseInfo",
    method: "PUT",
    data
  });
}
function UpdateAvatar(name) {
  return utils_request.request({
    url: `/api/permission/Users/Current/Avatar/${name}`,
    method: "PUT"
  });
}
const getGroupSelector = () => {
  return utils_request.request({
    url: "/api/permission/Group/Selector",
    method: "GET"
  });
};
const getGroupCondition = (data) => {
  return utils_request.request({
    url: "/api/permission/Group/GroupCondition",
    method: "POST",
    data
  });
};
const getRoleSelector = () => {
  return utils_request.request({
    url: "/api/permission/Role/Selector",
    method: "GET",
    options: {
      load: false
    }
  });
};
const getRoleCondition = (data) => {
  return utils_request.request({
    url: "/api/permission/Role/RoleCondition",
    method: "POST",
    data
  });
};
function getLoginConfig() {
  return utils_request.request({
    url: "/api/oauth/getLoginConfig"
  });
}
function getTicket() {
  return utils_request.request({
    url: `/api/oauth/getTicket`,
    method: "GET"
  });
}
function getTicketStatus(ticket) {
  return utils_request.request({
    url: `/api/oauth/getTicketStatus/${ticket}`,
    method: "GET"
  });
}
function socialsLogin(data) {
  return utils_request.request({
    url: `/api/oauth/Login/socials`,
    data,
    header: {
      "Content-Type": "application/x-www-form-urlencoded"
    }
  });
}
const getSignImgList = () => {
  return utils_request.request({
    url: "/api/permission/Users/Current/SignImg",
    method: "GET",
    options: {
      load: false
    }
  });
};
const createSignImg = (data) => {
  return utils_request.request({
    url: "/api/permission/Users/Current/SignImg",
    method: "post",
    data,
    options: {
      load: false
    }
  });
};
const setDefSignImg = (id) => {
  return utils_request.request({
    url: `/api/permission/Users/Current/${id}/SignImg`,
    method: "put",
    options: {
      load: false
    }
  });
};
const delSignImg = (id) => {
  return utils_request.request({
    url: `/api/permission/Users/Current/${id}/SignImg`,
    method: "delete",
    options: {
      load: false
    }
  });
};
const getSelectedList = (ids) => {
  return utils_request.request({
    url: "/api/permission/Users/getSelectedList",
    method: "post",
    data: {
      ids
    }
  });
};
const getSelectedUserList = (data) => {
  return utils_request.request({
    url: "/api/permission/Users/getSelectedUserList",
    method: "post",
    data
  });
};
function getAroundList(data) {
  return utils_request.request({
    url: "/api/system/Location/around",
    method: "get",
    data
  });
}
function getTextList(data) {
  return utils_request.request({
    url: "/api/system/Location/text",
    method: "get",
    data
  });
}
function getAddress(data) {
  return utils_request.request({
    url: "/api/system/Location/regeo",
    method: "get",
    data
  });
}
function setCodeCertificateStatus(ticket, status) {
  return utils_request.request({
    url: `/api/oauth/setCodeCertificateStatus/${ticket}/${status}`,
    method: "GET",
    options: {
      load: false
    }
  });
}
function confirmLogin(ticket) {
  return utils_request.request({
    url: `/api/oauth/confirmLogin/${ticket}`,
    method: "GET",
    options: {
      load: false
    }
  });
}
exports.UpdateAvatar = UpdateAvatar;
exports.UpdateUser = UpdateUser;
exports.UserSettingInfo = UserSettingInfo;
exports.accountCancel = accountCancel;
exports.confirmLogin = confirmLogin;
exports.createSignImg = createSignImg;
exports.delSignImg = delSignImg;
exports.getAddress = getAddress;
exports.getAppVersion = getAppVersion;
exports.getAroundList = getAroundList;
exports.getBillNumber = getBillNumber;
exports.getConfig = getConfig;
exports.getCurrentUser = getCurrentUser;
exports.getDataChange = getDataChange;
exports.getDataInterfaceDataInfoByIds = getDataInterfaceDataInfoByIds;
exports.getDataInterfaceRes = getDataInterfaceRes;
exports.getDepartmentSelector = getDepartmentSelector;
exports.getDictionaryDataAll = getDictionaryDataAll;
exports.getDictionaryDataSelector = getDictionaryDataSelector;
exports.getDownloadUrl = getDownloadUrl;
exports.getGroupCondition = getGroupCondition;
exports.getGroupSelector = getGroupSelector;
exports.getImUser = getImUser;
exports.getLoginConfig = getLoginConfig;
exports.getOrgByOrganizeCondition = getOrgByOrganizeCondition;
exports.getOrganization = getOrganization;
exports.getOrganizeSelector = getOrganizeSelector;
exports.getPopSelect = getPopSelect;
exports.getPositionByPositionCondition = getPositionByPositionCondition;
exports.getPositionSelector = getPositionSelector;
exports.getProvinceSelector = getProvinceSelector;
exports.getProvinceSelectorInfoList = getProvinceSelectorInfoList;
exports.getRelationSelect = getRelationSelect;
exports.getRoleCondition = getRoleCondition;
exports.getRoleSelector = getRoleSelector;
exports.getSelectedList = getSelectedList;
exports.getSelectedUserList = getSelectedUserList;
exports.getSignImgList = getSignImgList;
exports.getSubordinate = getSubordinate;
exports.getSubordinates = getSubordinates;
exports.getSystemConfig = getSystemConfig;
exports.getTextList = getTextList;
exports.getTicket = getTicket;
exports.getTicketStatus = getTicketStatus;
exports.getUesrDetail = getUesrDetail;
exports.getUserAll = getUserAll;
exports.getUserInfoList = getUserInfoList;
exports.getUserOrganizes = getUserOrganizes;
exports.getUserPositions = getUserPositions;
exports.getUserSelector = getUserSelector;
exports.getUserSelectorNew = getUserSelectorNew;
exports.login = login;
exports.logout = logout;
exports.setCodeCertificateStatus = setCodeCertificateStatus;
exports.setDefSignImg = setDefSignImg;
exports.setMajor = setMajor;
exports.socialsLogin = socialsLogin;
exports.updatePassword = updatePassword;
exports.updatePasswordMessage = updatePasswordMessage;
